Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Player ¶
type Player struct {
ID string
LastName string
FirstName string
JerseyNumber string
Position string
PicURL string
Age string
Height string
Weight string
Rookie bool
NflID string
TeamID string
Team Team
Stats []Stat `json:"stats"`
}
Player is the type that holds all player information
type Point ¶
type Point struct {
ID uint `json:"id" gorm:"primary_key"`
PlayerID string `json:"pid"`
Category string `json:"category"`
Abbreviation string `json:"shortname"`
Name string `json:"name"`
LeagueName string `json:"leaguename"` //The name the league uses on how it counts points (ie, RY10)
StatID int `json:"statid"` //Matching id
StatNum float64 `json:"stat"`
Value float64 `json:"points"`
}
Point stores list of fantasy points. Assigned to a player.
Click to show internal directories.
Click to hide internal directories.